@@ -22,16 +22,19 @@ Then open ``build/html/index.html`` in your web browser.  If that fails, you can
 
 """
 
-__version__ = "1.5.1"
+from pkg_resources import get_distribution
+
+__version__ = get_distribution("fixture").version
 
 import logging
 import sys
 
-from fixture.loadable import *
 from fixture.dataset import *
-from fixture.util import *
 from fixture.io import *
+from fixture.loadable import *
 from fixture.style import *
+from fixture.util import *
+
 
 def setup_test_not_supported():
     """hook for setup for the test command."""
