@@ -6,16 +6,16 @@ class code_str(str):
     def __repr__(self):
         return str.__repr__(self)[1:-1]
 
-import generate
-from generate import *
+from fixture.command.generate import generate
 __doc__ = generate.__doc__
+from fixture.command.generate.generate import *
 
 # load modules so they can register themselves (better way?)
 try:
-    import generate_sqlobject
+    from fixture.command.generate import generate_sqlobject
 except ImportError:
     pass
 try:
-    import generate_sqlalchemy
+    from fixture.command.generate import generate_sqlalchemy
 except ImportError:
     pass
\ No newline at end of file
